%global toolchain clang

%global baserelease 5

%global _python_bytecompile_extra %nil
# (tv) fix build with latest python-srpm-macros:
%global __brp_fix_pyc_reproducibility /bin/true

%bcond_with compat_build
%bcond_without check

%global maj_ver 15
%global min_ver 0
%global patch_ver 6
#global rc_ver 3
%global clang_version %{maj_ver}.%{min_ver}.%{patch_ver}

%define _disable_ld_no_undefined 0

# (tv) fix requires:
%global __requires_exclude devel\\(libclang
# (tv) fix deps:
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}^/usr/bin/tcsh

%define major %maj_ver.%min_ver
%define minor 1

%define libname %mklibname clang %major
%define devname %mklibname -d clang

%if %{with compat_build}
%global pkg_name clang%{maj_ver}
# Install clang to same prefix as llvm, so that apps that use llvm-config
# will also be able to find clang libs.
%global install_prefix %{_libdir}/llvm%{maj_ver}
%global install_bindir %{install_prefix}/bin
%global install_includedir %{install_prefix}/include
%global install_libdir %{install_prefix}/lib
%global pkg_bindir %{install_bindir}
%global pkg_includedir %{install_includedir}
%global pkg_libdir %{install_libdir}
%else
%global pkg_name clang
%global install_prefix /usr
%global pkg_libdir %{_libdir}
%endif

%bcond_without python3

%global clang_srcdir clang-%{clang_version}%{?rc_ver:rc%{rc_ver}}.src
%global clang_tools_srcdir clang-tools-extra-%{clang_version}%{?rc_ver:rc%{rc_ver}}.src

%if !%{maj_ver} && 0%{?rc_ver}
%global abi_revision 2
%endif

Name:		%pkg_name
Version:	%{clang_version}%{?rc_ver:~rc%{rc_ver}}
Release:	%mkrel %{?rc_ver:0.}%{baserelease}%{?rc_ver:.rc%{rc_ver}}
Summary:	A C language family front-end for LLVM
Group:		Development/Other

License:	NCSA
URL:		https://llvm.org/
Source0:	https://github.com/llvm/llvm-project/releases/download/llvmorg-%{clang_version}%{?rc_ver:-rc%{rc_ver}}/%{clang_srcdir}.tar.xz
Source3:	https://github.com/llvm/llvm-project/releases/download/llvmorg-%{clang_version}%{?rc_ver:-rc%{rc_ver}}/%{clang_srcdir}.tar.xz.sig
%if %{without compat_build}
Source1:	https://github.com/llvm/llvm-project/releases/download/llvmorg-%{clang_version}%{?rc_ver:-rc%{rc_ver}}/%{clang_tools_srcdir}.tar.xz
Source2:	https://github.com/llvm/llvm-project/releases/download/llvmorg-%{clang_version}%{?rc_ver:-rc%{rc_ver}}/%{clang_tools_srcdir}.tar.xz.sig
%endif
Source4:	release-keys.asc
%if %{without compat_build}
Source5:	macros.%{name}
%endif

# Patches for clang
Patch0:     0001-PATCH-clang-Reorganize-gtest-integration.patch
Patch1:     0003-PATCH-Make-funwind-tables-the-default-on-all-archs.patch
Patch2:     0003-PATCH-clang-Don-t-install-static-libraries.patch
Patch3:     0001-Driver-Add-a-gcc-equivalent-triple-to-the-list-of-tr.patch
Patch4:     0001-cmake-Allow-shared-libraries-to-customize-the-soname.patch
Patch5:     0010-PATCH-clang-Produce-DWARF4-by-default.patch

# TODO: Can be dropped in LLVM 16: https://reviews.llvm.org/D133316
Patch7:     0001-Mark-fopenmp-implicit-rpath-as-NoArgumentUnused.patch

# TODO: Can be dropped in LLVM 16: https://reviews.llvm.org/D134362
Patch8:     0001-clang-Fix-interaction-between-asm-labels-and-inline-.patch

# TODO: Can be dropped in LLVM 16.
Patch9:     0001-clang-MinGW-Improve-extend-the-gcc-sysroot-detection.patch
Patch10:    0002-clang-MinGW-Improve-detection-of-libstdc-headers-on-.patch

%if %{without compat_build}
# Patches for clang-tools-extra
# See https://reviews.llvm.org/D120301
Patch201:   0001-clang-tools-extra-Make-test-dependency-on-LLVMHello-.patch
%endif

Patch100:	cfe-14.0.0-detect-Mageia.patch

BuildRequires:	clang
BuildRequires:	cmake
BuildRequires:	ninja-build
%if %{with compat_build}
BuildRequires:	llvm%{maj_ver}-devel = %{version}
BuildRequires:	llvm%{maj_ver}-static = %{version}
%else
BuildRequires:	llvm-devel = %{version}
BuildRequires:	llvm-test = %{version}
# llvm-static is required, because clang-tablegen needs libLLVMTableGen, which
# is not included in libLLVM.so.
BuildRequires:  llvm-static = %{version}
BuildRequires:	llvm-googletest = %{version}
%endif

BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:  ncurses-devel
# According to https://fedoraproject.org/wiki/Packaging:Emacs a package
# should BuildRequires: emacs if it packages emacs integration files.
# (tv): emacs-nox doesn't pull mesa (& thus llvm12)
BuildRequires:	emacs-nox

# These build dependencies are required for the test suite.
%if %with python3
# The testsuite uses /usr/bin/lit which is part of the python3-lit package.
BuildRequires:  python3-lit
%endif

BuildRequires: python3-sphinx
BuildRequires:	python3-recommonmark
BuildRequires: libatomic-devel

# We need python3-devel for %%py3_shebang_fix
BuildRequires:	python3-devel

%if %{without compat_build}
# For reproducible pyc file generation
# See https://docs.fedoraproject.org/en-US/packaging-guidelines/Python_Appendix/#_byte_compilation_reproducibility
#BuildRequires: /usr/bin/marshalparser
%global py_reproducible_pyc_path %{buildroot}%{python3_sitelib}
%endif

# For origin certification
BuildRequires:	gnupg2

# scan-build uses these perl modules so they need to be installed in order
# to run the tests.
BuildRequires: perl(Digest::MD5)
BuildRequires: perl(File::Copy)
BuildRequires: perl(File::Find)
BuildRequires: perl(File::Path)
BuildRequires: perl(File::Temp)
BuildRequires: perl(FindBin)
BuildRequires: perl(Hash::Util)
BuildRequires: perl(lib)
BuildRequires: perl(Term::ANSIColor)
BuildRequires: perl(Text::ParseWords)
BuildRequires: perl(Sys::Hostname)

Requires:	%{libname} = %{version}-%{release}

# clang requires gcc, clang++ requires libstdc++-devel
# - https://bugzilla.redhat.com/show_bug.cgi?id=1021645
# - https://bugzilla.redhat.com/show_bug.cgi?id=1158594
Requires:	libstdc++-static-devel
Requires:	gcc-c++

Provides: clang(major) = %{maj_ver}

Conflicts:	compiler-rt < 11.0.0

%description
clang: noun
    1. A loud, resonant, metallic sound.
    2. The strident call of a crane or goose.
    3. C-language family front-end toolkit.

The goal of the Clang project is to create a new C, C++, Objective C
and Objective C++ front-end for the LLVM compiler. Its tools are built
as libraries and designed to be loosely-coupled and extensible.

Install compiler-rt if you want the Blocks C language extension or to
enable sanitization and profiling options when building, and
libomp-devel to enable -fopenmp.

%package -n %libname
Summary: Runtime library for clang
# (tv) relaxed for upgrade vs libification:
Requires: %{name}-resource-filesystem%{?_isa} >= %{version}
Recommends: compiler-rt%{?_isa} = %{version}
# atomic support is not part of compiler-rt
Recommends: libatomic1%{?_isa}
# libomp-devel is required, so clang can find the omp.h header when compiling
# with -fopenmp.
Recommends: libomp-devel%{_isa} = %{version}
Recommends: libomp%{_isa} = %{version}

# Use lld as the default linker on ARM due to rhbz#1918924
%ifarch %{arm}
Requires: lld
%endif

%description -n %libname
Runtime library for clang.

%package -n %devname
Summary: Development header files for clang
Provides: clang-devel = %version-%release
Requires: %{libname} = %{version}-%{release}
%if %{without compat_build}
Requires: %{name}%{?_isa} = %{version}-%{release}
# The clang CMake files reference tools from clang-tools-extra.
Requires: %{name}-tools-extra%{?_isa} = %{version}-%{release}
%endif

%description -n %devname
Development header files for clang.

%package resource-filesystem
Summary: Filesystem package that owns the clang resource directory
Provides: %{name}-resource-filesystem(major) = %{maj_ver}

%description resource-filesystem
This package owns the clang resource directory: $libdir/clang/$version/

%if %{without compat_build}
%package analyzer
Summary:	A source code analysis framework
License:	NCSA and MIT
BuildArch:	noarch
Requires:	%{name} = %{version}-%{release}

%description analyzer
The Clang Static Analyzer consists of both a source code analysis
framework and a standalone tool that finds bugs in C and Objective-C
programs. The standalone tool is invoked from the command-line, and is
intended to run in tandem with a build of a project or code base.

%package tools-extra
Summary: Extra tools for clang
Group:	 Development/Other
Requires: %{mklibname clang %major}%{?_isa} = %{version}
Requires: %libname%{?_isa} = %{version}

%description tools-extra
A set of extra tools built using Clang's tooling API.

# Put git-clang-format in its own package, because it Requires git
# and we don't want to force users to install all those dependenices if they
# just want clang.
%package -n git-clang-format
Summary:	Integration of clang-format for git
Group:	 Development/Other
Requires:	%{name}-tools-extra = %{version}-%{release}
Requires: git
Requires: python3

%description -n git-clang-format
clang-format integration for git.


%package -n python3-clang
Summary: Python3 bindings for clang
Requires: %{devname}%{?_isa} = %{version}-%{release}
Requires: python3
%description -n python3-clang
%{summary}.


%endif


%prep
%{gpgverify} --keyring='%{SOURCE4}' --signature='%{SOURCE3}' --data='%{SOURCE0}'

%if %{with compat_build}
%autosetup -n %{clang_srcdir} -p2
%else

%{gpgverify} --keyring='%{SOURCE4}' --signature='%{SOURCE2}' --data='%{SOURCE1}'
%setup -T -q -b 1 -n %{clang_tools_srcdir}
%autopatch -m200 -p2


# failing test case
rm test/clang-tidy/checkers/altera/struct-pack-align.cpp

%py3_shebang_fix \
	clang-tidy/tool/ \
	clang-include-fixer/find-all-symbols/tool/run-find-all-symbols.py

%setup -q -n %{clang_srcdir}
%autopatch -M200 -p2

# failing test case
rm test/CodeGen/profile-filter.c

%py3_shebang_fix \
	tools/clang-format/ \
	tools/clang-format/git-clang-format \
	utils/hmaptool/hmaptool \
	tools/scan-view/bin/scan-view \
	tools/scan-view/share/Reporter.py \
	tools/scan-view/share/startfile.py \
	tools/scan-build-py/bin/* \
	tools/scan-build-py/libexec/*
%endif

%build

%if 0%{?__isa_bits} == 64
sed -i 's/\@FEDORA_LLVM_LIB_SUFFIX\@/64/g' test/lit.cfg.py
%else
sed -i 's/\@FEDORA_LLVM_LIB_SUFFIX\@//g' test/lit.cfg.py
%endif

# FC compatibility:
%global _vpath_builddir _build

%ifarch s390 s390x %{arm} aarch64 %ix86 ppc64le
# Decrease debuginfo verbosity to reduce memory consumption during final library linking
%global optflags %(echo %{optflags} | sed 's/-g /-g1 /')
%endif

# Disable dwz on aarch64, because it takes a huge amount of time to decide not to optimize things.
%ifarch aarch64
%define _find_debuginfo_dwz_opts %{nil}
%endif

# We set CLANG_DEFAULT_PIE_ON_LINUX=OFF and PPC_LINUX_DEFAULT_IEEELONGDOUBLE=ON to match the
# defaults used by Fedora's GCC.
%cmake  -G Ninja \
	-DCLANG_DEFAULT_PIE_ON_LINUX=OFF \
%if 0%{?fedora}
	-DPPC_LINUX_DEFAULT_IEEELONGDOUBLE=ON \
%endif
	-DLLVM_PARALLEL_LINK_JOBS=1 \
	-DLLVM_LINK_LLVM_DYLIB:BOOL=ON \
	-DCMAKE_BUILD_TYPE=RelWithDebInfo \
	-DPYTHON_EXECUTABLE=%{__python3} \
	-DCMAKE_SKIP_RPATH:BOOL=ON \
%ifarch s390 s390x %{arm} %ix86 ppc64le
	-DCMAKE_C_FLAGS_RELWITHDEBINFO="%{optflags} -DNDEBUG" \
	-DCMAKE_CXX_FLAGS_RELWITHDEBINFO="%{optflags} -DNDEBUG" \
%endif
%if %{with compat_build}
	-DCLANG_BUILD_TOOLS:BOOL=OFF \
	-DLLVM_CMAKE_DIR=%{install_libdir}/cmake/llvm \
	-DCMAKE_INSTALL_PREFIX=%{install_prefix} \
	-DCLANG_INCLUDE_TESTS:BOOL=OFF \
%else
	-DCLANG_INCLUDE_TESTS:BOOL=ON \
	-DLLVM_BUILD_UTILS:BOOL=ON \
	-DLLVM_EXTERNAL_CLANG_TOOLS_EXTRA_SOURCE_DIR=../%{clang_tools_srcdir} \
	-DLLVM_EXTERNAL_LIT=%{_bindir}/lit \
	-DLLVM_MAIN_SRC_DIR=%{_datadir}/llvm/src \
%if 0%{?__isa_bits} == 64
	-DLLVM_LIBDIR_SUFFIX=64 \
%else
	-DLLVM_LIBDIR_SUFFIX= \
%endif
%endif
	\
%if %{with compat_build}
	-DLLVM_TABLEGEN_EXE:FILEPATH=%{_bindir}/llvm-tblgen-%{maj_ver} \
%else
	-DLLVM_TABLEGEN_EXE:FILEPATH=%{_bindir}/llvm-tblgen \
%endif
	-DCLANG_ENABLE_ARCMT:BOOL=ON \
	-DCLANG_ENABLE_STATIC_ANALYZER:BOOL=ON \
	-DCLANG_INCLUDE_DOCS:BOOL=ON \
	-DCLANG_PLUGIN_SUPPORT:BOOL=ON \
	-DENABLE_LINKER_BUILD_ID:BOOL=ON \
	-DLLVM_ENABLE_EH=ON \
	-DLLVM_ENABLE_RTTI=ON \
	-DLLVM_BUILD_DOCS=ON \
	-DLLVM_ENABLE_SPHINX=ON \
	-DCLANG_LINK_CLANG_DYLIB=ON \
	%{?abi_revision:-DLLVM_ABI_REVISION=%{abi_revision}} \
	-DSPHINX_WARNINGS_AS_ERRORS=OFF \
	\
	-DCLANG_BUILD_EXAMPLES:BOOL=OFF \
	-DBUILD_SHARED_LIBS=OFF \
	-DCLANG_REPOSITORY_STRING="%{?mageia:Mageia}%{?rhel:Red Hat} %{version}-%{release}" \
%ifarch %{arm}
	-DCLANG_DEFAULT_LINKER=lld \
%endif
	-DCLANG_DEFAULT_UNWINDLIB=libgcc

%cmake_build

%install

%cmake_install

%if %{with compat_build}

# Remove binaries/other files
rm -Rf %{buildroot}%{install_bindir}
rm -Rf %{buildroot}%{install_prefix}/share
rm -Rf %{buildroot}%{install_prefix}/libexec
# Remove scanview-py helper libs
rm -Rf %{buildroot}%{install_prefix}/lib/{libear,libscanbuild}

%else

# File in the macros file for other packages to use.  We are not doing this
# in the compat package, because the version macros would # conflict with
# eachother if both clang and the clang compat package were installed together.
install -p -m0644 -D %{SOURCE5} %{buildroot}%{_rpmmacrodir}/macros.%{name}
sed -i -e "s|@@CLANG_MAJOR_VERSION@@|%{maj_ver}|" \
       -e "s|@@CLANG_MINOR_VERSION@@|%{min_ver}|" \
       -e "s|@@CLANG_PATCH_VERSION@@|%{patch_ver}|" \
       %{buildroot}%{_rpmmacrodir}/macros.%{name}

# install clang python bindings
mkdir -p %{buildroot}%{python3_sitelib}/clang/
install -p -m644 bindings/python/clang/* %{buildroot}%{python3_sitelib}/clang/
%py_byte_compile %{__python3} %{buildroot}%{python3_sitelib}/clang

# install scanbuild-py to python sitelib.
mv %{buildroot}%{_prefix}/lib/{libear,libscanbuild} %{buildroot}%{python3_sitelib}
%py_byte_compile %{__python3} %{buildroot}%{python3_sitelib}/{libear,libscanbuild}

# Fix permissions of scan-view scripts
chmod a+x %{buildroot}%{_datadir}/scan-view/{Reporter.py,startfile.py}

# Move emacs integration files to the correct directory
mkdir -p %{buildroot}%{_emacs_sitestartdir}
for f in clang-format.el clang-rename.el clang-include-fixer.el; do
mv %{buildroot}{%{_datadir}/clang,%{_emacs_sitestartdir}}/$f
done

# remove editor integrations (bbedit, sublime, emacs, vim)
rm -vf %{buildroot}%{_datadir}/clang/clang-format-bbedit.applescript
rm -vf %{buildroot}%{_datadir}/clang/clang-format-sublime.py*

# TODO: Package html docs
rm -Rvf %{buildroot}%{_docdir}/Clang/clang/html
rm -Rvf %{buildroot}%{_datadir}/clang/clang-doc-default-stylesheet.css
rm -Rvf %{buildroot}%{_datadir}/clang/index.js

# TODO: What are the Fedora guidelines for packaging bash autocomplete files?
rm -vf %{buildroot}%{_datadir}/clang/bash-autocomplete.sh

# Create Manpage symlinks
ln -s clang.1.xz %{buildroot}%{_mandir}/man1/clang++.1.xz
ln -s clang.1.xz %{buildroot}%{_mandir}/man1/clang-%{maj_ver}.1.xz
ln -s clang.1.xz %{buildroot}%{_mandir}/man1/clang++-%{maj_ver}.1.xz

# Add clang++-{version} symlink
ln -s clang++ %{buildroot}%{_bindir}/clang++-%{maj_ver}


# Fix permission
chmod u-x %{buildroot}%{_mandir}/man1/scan-build.1*

# create a link to clang's resource directory that is "constant" across minor
# version bumps
# this is required for packages like ccls that hardcode the link to clang's
# resource directory to not require rebuilds on minor version bumps
# Fix for bugs like rhbz#1807574
pushd %{buildroot}%{_libdir}/clang/
ln -s %{version} %{maj_ver}
popd

%endif

# Create sub-directories in the clang resource directory that will be
# populated by other packages
mkdir -p %{buildroot}%{pkg_libdir}/clang/%{version}/{include,lib,share}/


# Remove clang-tidy headers.  We don't ship the libraries for these.
rm -Rvf %{buildroot}%{_includedir}/clang-tidy/

%if %{without compat_build}
# Add a symlink in /usr/bin to clang-format-diff
ln -s %{_datadir}/clang/clang-format-diff.py %{buildroot}%{_bindir}/clang-format-diff
%endif

%check
%if %{without compat_build}
%if %{with check}
# Build test dependencies separately, to prevent invocations of host clang from being affected
# by LD_LIBRARY_PATH below.
%cmake_build --target clang-test-depends \
    ExtraToolsUnitTests ClangdUnitTests ClangIncludeCleanerUnitTests ClangPseudoUnitTests
# requires lit.py from LLVM utilities
# FIXME: Fix failing ARM tests
LD_LIBRARY_PATH=%{buildroot}/%{_libdir} %{__ninja} check-all -C %{__cmake_builddir} || \
%ifarch %{arm}
:
%else
:
%endif
%endif
%endif


%if %{without compat_build}
%files
%license LICENSE.TXT
%{_bindir}/clang
%{_bindir}/clang++
%{_bindir}/clang-%{maj_ver}
%{_bindir}/clang++-%{maj_ver}
%{_bindir}/clang-cl
%{_bindir}/clang-cpp
%{_mandir}/man1/clang.1*
%{_mandir}/man1/clang++.1*
%{_mandir}/man1/clang-%{maj_ver}.1.*
%{_mandir}/man1/clang++-%{maj_ver}.1.*
%endif

%files -n %libname
%if %{without compat_build}
%{_libdir}/clang/%{version}/include/*
%{_libdir}/*.so.*
%else
%{pkg_libdir}/*.so.*
%{pkg_libdir}/clang/%{version}/include/*
%endif

%files -n %devname
%if %{without compat_build}
%{_libdir}/*.so
%{_includedir}/clang/
%{_includedir}/clang-c/
%{_libdir}/cmake/*
%{_bindir}/clang-tblgen
%dir %{_datadir}/clang/
%{_rpmmacrodir}/macros.%{name}
%else
%{pkg_libdir}/*.so
%{pkg_includedir}/clang/
%{pkg_includedir}/clang-c/
%{pkg_libdir}/cmake/
%endif

%files resource-filesystem
%dir %{pkg_libdir}/clang/
%dir %{pkg_libdir}/clang/%{version}/
%dir %{pkg_libdir}/clang/%{version}/include/
%dir %{pkg_libdir}/clang/%{version}/lib/
%dir %{pkg_libdir}/clang/%{version}/share/
%if %{without compat_build}
%{pkg_libdir}/clang/%{maj_ver}
%endif

%if %{without compat_build}
%files analyzer
%{_bindir}/scan-view
%{_bindir}/scan-build
%{_bindir}/analyze-build
%{_bindir}/intercept-build
%{_bindir}/scan-build-py
%{_libexecdir}/ccc-analyzer
%{_libexecdir}/c++-analyzer
%{_libexecdir}/analyze-c++
%{_libexecdir}/analyze-cc
%{_libexecdir}/intercept-c++
%{_libexecdir}/intercept-cc
%{_datadir}/scan-view/
%{_datadir}/scan-build/
%{_mandir}/man1/scan-build.1.*
%{python3_sitelib}/libear
%{python3_sitelib}/libscanbuild


%files tools-extra
%{_bindir}/clang-apply-replacements
%{_bindir}/clang-change-namespace
%{_bindir}/clang-check
%{_bindir}/clang-doc
%{_bindir}/clang-extdef-mapping
%{_bindir}/clang-format
%{_bindir}/clang-include-fixer
%{_bindir}/clang-move
%{_bindir}/clang-offload-bundler
%{_bindir}/clang-offload-packager
%{_bindir}/clang-offload-wrapper
%{_bindir}/clang-linker-wrapper
%{_bindir}/clang-nvlink-wrapper
%{_bindir}/clang-pseudo
%{_bindir}/clang-query
%{_bindir}/clang-refactor
%{_bindir}/clang-rename
%{_bindir}/clang-reorder-fields
%{_bindir}/clang-repl
%{_bindir}/clang-scan-deps
%{_bindir}/clang-tidy
%{_bindir}/clangd
%{_bindir}/diagtool
%{_bindir}/hmaptool
%{_bindir}/pp-trace
%{_bindir}/c-index-test
%{_bindir}/find-all-symbols
%{_bindir}/modularize
%{_bindir}/clang-format-diff
%{_mandir}/man1/diagtool.1*
%{_emacs_sitestartdir}/clang-format.el
%{_emacs_sitestartdir}/clang-rename.el
%{_emacs_sitestartdir}/clang-include-fixer.el
%{_datadir}/clang/clang-format.py*
%{_datadir}/clang/clang-format-diff.py*
%{_datadir}/clang/clang-include-fixer.py*
%{_datadir}/clang/clang-tidy-diff.py*
%{_bindir}/run-clang-tidy
%{_datadir}/clang/run-find-all-symbols.py*
%{_datadir}/clang/clang-rename.py*

%files -n git-clang-format
%{_bindir}/git-clang-format

%files -n python3-clang
%{python3_sitelib}/clang/

%endif


%changelog
* Thu Feb 02 2023 wally <wally> 15.0.6-5.mga9
+ Revision: 1937592
- don't ship directories from clang-resource-filesystem in lib pkg

* Fri Dec 23 2022 tv <tv> 15.0.6-4.mga9
+ Revision: 1926012
- Backport patches for ucrt64 toolchain detection

* Thu Dec 22 2022 tv <tv> 15.0.6-3.mga9
+ Revision: 1925763
- Add clang-devel dep to python3-clang

* Thu Dec 08 2022 tv <tv> 15.0.6-2.mga9
+ Revision: 1919380
- Update to LLVM 15.0.6

* Fri Nov 04 2022 tv <tv> 15.0.4-2.mga9
+ Revision: 1902624
- Update to LLVM 15.0.4
- Add patch for inline builtins with asm label

* Fri Oct 21 2022 tv <tv> 15.0.0-2.mga9
+ Revision: 1898156
- Default to non-PIE like gcc

* Wed Sep 21 2022 tv <tv> 15.0.0-1.mga9
+ Revision: 1891052
- Update to LLVM 15.0.0
- Downgrade implicit int and implicit function declaration to warning only
- Add a Recommends on libatomic1 (rhbz#2118592)

* Sat Jun 18 2022 tv <tv> 14.0.5-1.mga9
+ Revision: 1864769
- fix build with latest python-srpm-macros
- Update to 14.0.5
- 14.0.3 Release

* Fri Apr 01 2022 tv <tv> 14.0.0-3.mga9
+ Revision: 1839229
- Fix conflicts

* Thu Mar 31 2022 tv <tv> 14.0.0-2.mga9
+ Revision: 1837048
- Explicitely conflicts with lib(64)clang13 as not all libs were bumped to 14 :-(

* Wed Mar 30 2022 tmb <tmb> 14.0.0-1.mga9
+ Revision: 1834666
- fix filelist
+ tv <tv>
- Update to 14.0.0

* Thu Feb 03 2022 tv <tv> 13.0.1-1.mga9
+ Revision: 1771224
- Update to 13.0.1 final
- Make lld the default linker on arm
- Remove Conflicts: compiler-rt for newer versions of compiler-rt

* Wed Oct 20 2021 tv <tv> 13.0.0-1.mga9
+ Revision: 1752281
- BR emacs-nox instead of emacs in order not to pull llvm12
- 13.0.0 Release
- Fix compat build
- Add macros.clang file
- Add --without=check option

* Mon Jul 19 2021 tv <tv> 12.0.1-1.mga9
+ Revision: 1736990
- 12.0.1 Release
- Only enable -funwind-tables by default on CPU arches
  .eh_frame sections confuse bpf tools, so -funwind-tables  shouldn't be enabled there.

* Fri Apr 30 2021 akien <akien> 12.0.0-3.mga9
+ Revision: 1720592
- Fix cfe-12.0.0-detect-Mageia.patch after GCC 11 triplet change

* Fri Apr 30 2021 akien <akien> 12.0.0-2.mga9
+ Revision: 1720536
- Rebuild for GCC 11
+ tv <tv>
- Add a symlink in /usr/bin to clang-format-diff

* Fri Apr 16 2021 tv <tv> 12.0.0-1.mga9
+ Revision: 1715989
- 12.0.0 final

* Fri Apr 09 2021 tv <tv> 12.0.0-0.11.rc5.mga9
+ Revision: 1714250
- 12.0.0 RC5
- 12.0.0 RC5

* Fri Apr 02 2021 tv <tv> 12.0.0-0.5.1.rc4.mga9
+ Revision: 1712619
- BS still run mga7 and thus %%autopatch does not know about -m/-M
- 12.0.0 RC4
- Set CLANG_DEFAULT_UNWIND_LIB instead of using custom patch

* Fri Mar 12 2021 tv <tv> 12.0.0-0.5.rc3.mga9
+ Revision: 1701719
- LLVM 12.0.0 rc3

* Tue Mar 02 2021 tv <tv> 12.0.0-0.3.rc2.mga9
+ Revision: 1696080
- reapply: Revert "scan-view: Remove Reporter.py and  associated AppleScript files"
- relax desp on resource-filesystem for easier upgrade

* Sun Feb 28 2021 tv <tv> 12.0.0-0.2.rc2.mga9
+ Revision: 1693196
- 12.0.0-rc2 release

* Thu Jan 07 2021 tv <tv> 11.0.1-4.mga8
+ Revision: 1669465
- LLVM 11.0.1 final

* Tue Dec 22 2020 tv <tv> 11.0.1-3.rc2.mga8
+ Revision: 1662958
- llvm 11.0.1-rc2

* Thu Dec 03 2020 tv <tv> 11.0.1-1.rc1.mga8
+ Revision: 1652052
- ignore testsuite failure for now
- llvm 11.0.1-rc1
- stop ignoring testsuite results

* Thu Nov 26 2020 tv <tv> 11.0.0-3.mga8
+ Revision: 1649427
- ignore %%check failure for now
- 11.0.0

* Fri Oct 16 2020 ghibo <ghibo> 10.0.1-2.mga8
+ Revision: 1636368
- Rebuild to fix weird package release number

* Thu Oct 08 2020 akien <akien> 10.0.1-1.1.mga8
+ Revision: 1632746
- Version 10.0.1
+ tv <tv>
- bump rel b/c previous build failed due to 0 free disk space :-(
- Update cmake macro usage
- Finalize source verification
- Add cet.h header
- Accept multiple --config options

* Thu Jun 04 2020 tv <tv> 10.0.0-4.mga8
+ Revision: 1590273
- Add symlink to %%{_libdir}/clang/%%{maj_ver} for persistent access to the resource directory accross minor version bumps

* Wed May 20 2020 tv <tv> 10.0.0-2.mga8
+ Revision: 1586350
- Backport "Fix undefined behaviour… `std::out_of_range` exception" (rhbz#1825593)

* Tue Mar 24 2020 tv <tv> 10.0.0-1.mga8
+ Revision: 1559495
- 10.0.0 final

* Tue Mar 24 2020 tv <tv> 10.0.0-0.10.rc5.mga8
+ Revision: 1559209
- Update git-clang-format dependency (rhbz#1815913)

* Sun Mar 22 2020 tv <tv> 10.0.0-0.9.rc5.mga8
+ Revision: 1558776
- Add dependency on libomp-devel

* Sun Mar 22 2020 tv <tv> 10.0.0-0.8.6.rc5.mga8
+ Revision: 1558758
- rebuild b/c of armv7 failure

* Sat Mar 21 2020 tv <tv> 10.0.0-0.8.5.rc5.mga8
+ Revision: 1558718
- rebuild for missing pkg on arm

* Sat Mar 21 2020 tv <tv> 10.0.0-0.8.4.rc5.mga8
+ Revision: 1558692
- rebuild for missing pkg on arm
- rebuild for missing pkg on arm

* Sat Mar 21 2020 tv <tv> 10.0.0-0.8.2.rc5.mga8
+ Revision: 1558630
- revert workaround now that BS is fixed
- compile with -O1 instead of -O2 on aarch64 x86_64 b/c of BS timeouts)
- 10.0.0 rc5
- 10.0.0 rc4
- remove old obsoletes
- add support for compat_build
- remove cpu & debug libmitations on aarch64 now that've fast BS
- Move clang-format.el along with tools-extra (rhbz#1812487)
  With the current setup, if you only install clang-tools-extra, the
  package clang-format is not found by Emacs.
  A similar change was made for the Python scripts

* Thu Mar 05 2020 tv <tv> 10.0.0-0.5.rc3.mga8
+ Revision: 1554126
- 10.0.0 RC3
- 10.0.0 rc2
- Explicitly conflicts with any different compiler-rt version (rhbz#1800705)

* Wed Feb 12 2020 tv <tv> 10.0.0-0.2.rc1.mga8
+ Revision: 1502233
- 10.0.0 rc1
- Stop shipping individual component libraries
- https://fedoraproject.org/wiki/Changes/Stop-Shipping-Individual-Component-Libraries-In-clang-lib-Package
+ wally <wally>
- build with new cmake macros

* Sat Sep 21 2019 tv <tv> 9.0.0-1.mga8
+ Revision: 1444193
- 9.0.0 Release

* Tue Sep 17 2019 tv <tv> 9.0.0-0.2.rc3.mga8
+ Revision: 1442787
- disable %%_python_bytecompile_extra
- drop BR on python2-lit
- 9.0.0 Release candidate 3
+ wally <wally>
- drop python2-sphinx BR

* Sat Apr 13 2019 tv <tv> 8.0.0-1.mga7
+ Revision: 1389634
- ignore one test failure for now
- 8.0.0 final
- Cleanup specfile after llvm dependency update
- Fix compiling with -stdlib=libc++
- Update patch for Python3 port of scan-view
- Working CI test suite
- Workaround gcc-9 bug when compiling bitfields
- Fix uninitialized error detected by gcc-9

* Sat Dec 29 2018 tv <tv> 7.0.1-1.mga7
+ Revision: 1346606
- 7.0.1
- Fix for rhbz#1657544
- Install proper manpage symlinks for clang/clang++ versions
- No longer Ignore -fstack-clash-protection option
- Ensure rpmlint passes on specfile
- Drop python2 dependency from clang-tools-extra
- Prune unneeded reference to llvm-test-suite sub-package
- Run 'make check-all' instead of 'make check-clang'

* Sun Oct 21 2018 tv <tv> 7.0.0-8.mga7
+ Revision: 1323172
- fix test-suite deps as we don't split libstdc++-static like FC

* Sat Oct 13 2018 tv <tv> 7.0.0-7.mga7
+ Revision: 1319966
- fix test deps

* Wed Oct 03 2018 wally <wally> 7.0.0-5.mga7
+ Revision: 1317201
- build with 4 cores max on aarch64

* Wed Oct 03 2018 tv <tv> 7.0.0-4.mga7
+ Revision: 1316091
- Use correct shebang substitution for python scripts
- Drop python2 dependency
+ wally <wally>
- add Mageia to clang repository string
+ pterjan <pterjan>
- Also decrease memory usage on aarch64
- Add aarch64 triple, it currently fails to find gcc headers
- Drop duplicate lines

* Sun Sep 23 2018 tv <tv> 7.0.0-2.mga7
+ Revision: 1302242
- drop armv5tl workarounds
- temp BR on python2-sphinx while waiting for new python3
- Move llvm-test-suite into a sub-package
- new release

* Sat Sep 22 2018 umeabot <umeabot> 6.0.1-2.mga7
+ Revision: 1296281
- Mageia 7 Mass Rebuild

* Thu Jun 28 2018 tv <tv> 6.0.1-1.mga7
+ Revision: 1240607
- 6.0.1

* Fri Jun 15 2018 tv <tv> 6.0.1-0.2.rc2.mga7
+ Revision: 1237000
- new release

* Thu May 31 2018 tv <tv> 6.0.1-0.2.rc1.mga7
+ Revision: 1233324
- move devel files into dev pkg
- fix major

* Tue May 15 2018 tv <tv> 6.0.1-0.1.rc1.mga7
+ Revision: 1229705
- 6.0.1-rc1 Release
- Decrease debuginfo verbosity on arm in order to reduce memory consumption
  during final library linking

* Sat Mar 24 2018 tv <tv> 6.0.0-6.mga7
+ Revision: 1211831
- Add a clang++-{version} symlink (rhbz#1534098)
- Use correct script for running lit tests

* Thu Mar 22 2018 tv <tv> 6.0.0-5.mga7
+ Revision: 1211318
- rediff mageia patch

* Thu Mar 22 2018 tv <tv> 6.0.0-4.mga7
+ Revision: 1211297
- Fix toolchain detection so we don't default to using cross-compilers
  (rhbz#14824b1)

* Tue Mar 20 2018 tv <tv> 6.0.0-3.mga7
+ Revision: 1210781
- fix filelist
- new release

* Tue Dec 26 2017 tv <tv> 5.0.1-3.mga7
+ Revision: 1185119
- 5.0.1
- Make compiler-rt a weak dependency and add a weak dependency on libomp

* Wed Nov 22 2017 tv <tv> 5.0.0-3.mga7
+ Revision: 1178837
- fix python2-clang's deps

* Wed Oct 25 2017 tv <tv> 5.0.0-2.mga7
+ Revision: 1173564
- bump major

* Wed Oct 18 2017 tv <tv> 5.0.0-1.mga7
+ Revision: 1172647
- rediff mga patch
- new release

* Fri Sep 22 2017 tv <tv> 4.0.1-11.mga7
+ Revision: 1156948
- make clang-devel requires clang

* Thu Sep 21 2017 tv <tv> 4.0.1-10.mga7
+ Revision: 1156908
- reenable mga patch

* Thu Sep 21 2017 tv <tv> 4.0.1-7.mga7
+ Revision: 1156811
- ignore more testsuite faillures
- fix mga patch
- bootstrap w/o mga patch
- fix build by BR python-sphinx
- new release
- new tools-extra & git-clang-format subpkgs (rhbz#1328091)
- Generate man pages
- Run llvm test-suite
- Enable build-id by default (rhbz#1432403)
- Enable eh/rtti, which are required by lldb

* Tue Mar 28 2017 tmb <tmb> 3.9.1-4.mga6
+ Revision: 1095109
- rebuild for armv7hl

* Tue Mar 28 2017 tmb <tmb> 3.9.1-3.mga6
+ Revision: 1095072
- dont require compiler-rt on armv5tl

* Tue Mar 28 2017 tmb <tmb> 3.9.1-2.mga6
+ Revision: 1095014
- rebuild with new llvm

* Sat Jan 07 2017 ghibo <ghibo> 3.9.1-1.mga6
+ Revision: 1080455
- Update to release 3.9.1.
- Removed GCC patches (merged upstream).
- Rework Patch10 for Mageia detecting.

* Mon Oct 03 2016 tv <tv> 3.8.1-4.mga6
+ Revision: 1058299
- add GCC abi_tag support (rhbz#1282645)

* Thu Sep 08 2016 pterjan <pterjan> 3.8.1-3.mga6
+ Revision: 1050874
- Add armv5tl-mageia-linux-gnueabi, hopefuly at the correct place
- Add armv7hl-mageia-linux-gnueabi
+ shlomif <shlomif>
- Fix clang invocation on mageia ( MGA#18138 ).
- Copy a patch from the old llvm package that was left out after clang was
  split from it. We still need to handle the ARM architecture.

* Tue Jul 12 2016 tmb <tmb> 3.8.1-2.mga6
+ Revision: 1041254
- update to 3.8.1 (maintenance release)

* Tue Mar 29 2016 pterjan <pterjan> 3.8.0-9.mga6
+ Revision: 996290
- Rebuild to get it on arm

* Tue Mar 15 2016 tv <tv> 3.8.0-8.mga6
+ Revision: 990894
- rebuild b/c clang-analyzer was not uploaded by BS

* Mon Mar 14 2016 tv <tv> 3.8.0-7.mga6
+ Revision: 990522
- submit to core/release

* Sat Mar 12 2016 tv <tv> 3.8.0-6.mga6
+ Revision: 989660
- fix lib requires
- provides clang-devel

* Sat Mar 12 2016 tv <tv> 3.8.0-4.mga6
+ Revision: 989586
- fix requires

* Sat Mar 12 2016 tv <tv> 3.8.0-3.mga6
+ Revision: 989532
- fix upload (summary-ended-with-dot)
- adjust file list
- fix linking
- 3.8.0 final
- imported package clang
+ tmb <tmb>
- try to disable parallell build


* Tue Mar 08 2016 Thierry Vignaud <tv@mageia.org> 3.8.0-1.mga6
- import from FC
